flutter_ble_central library
Classes
- BluetoothDevice
- Represents a Bluetooth device
- BondStateChange
-
A change in whether this device is paired with a peripheral, from
FlutterBleCentral.onBondStateChanged. - CharacteristicValue
-
A value a peripheral notified, from
FlutterBleCentral.onCharacteristicValueChanged. - ConnectionStateChange
-
A change in the link to a peripheral, from
FlutterBleCentral.onConnectionStateChanged. - FlutterBleCentral
- Main class for Flutter BLE Central plugin
- GattCharacteristic
- Represents a GATT characteristic
- GattCharacteristicProperties
- Properties of a GATT characteristic
- GattDescriptor
- Represents a GATT descriptor
- GattService
- Represents a GATT service
- ScanRecord
- Represents a BLE scan record
- ScanResult
- A scan result emitted by the scanning operation, containing BluetoothDevice and ScanRecord.
- ScanSettings
- A configuration model for controlling Bluetooth LE scan behavior on Android only.
Enums
- AndroidError
- Android BLE scan error codes
- BondState
- Whether this device is paired with a peripheral.
- CallbackType
- BLE scan callback type
- CentralBluetoothState
- Bluetooth Central state enum
- CentralState
- Central state enum
- ConnectionPriority
- How eagerly the connection should be serviced.
- GattConnectionState
- Represents the connection state of a Bluetooth device.
- GattPhy
- The physical layer a connection runs on.
- MatchMode
- Set match mode for Bluetooth LE scan filters hardware match.
- MatchNum
- Set the number of matches for Bluetooth LE scan filters hardware match. Determines how many advertisements to match per filter, as this is scarce hw resource.
- Phy
- Set the Physical Layer to use during this scan. This is used only if ScanSettings.Builder#setLegacy is set to false. BluetoothAdapter.isLeCodedPhySupported() may be used to check whether LE Coded phy is supported. Selecting an unsupported phy will result in failure to start scan. Physical Layer enum for BLE scanning
- PhyOption
- The coding to prefer on GattPhy.leCoded.
- ScanMode
- BLE scan mode enum
Extensions
- PeripheralStateExtension on CentralState
- Extension on CentralState to get numeric code
Typedefs
- BluetoothCentralState = CentralBluetoothState
- Former name of CentralBluetoothState.